'use strict';
import { AtajoXUtils } from "../utils/utils";
var AtajoXDevice = /** @class */ (function () {
    function AtajoXDevice() {
        this.battery = { level: 'unknown', isCharging: false };
        this.addBatteryEventListeners();
    }
    /**
     * Get device information
     *
     * @returns {Promise<DeviceModel>}
     */
    AtajoXDevice.prototype.getInformation = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            Promise.all([
                _this.getAppName(),
                _this.getPackageName(),
                _this.getVersionCode(),
                _this.getVersionNumber(),
                _this.getSignalStrength(),
                _this.getNetworkInformation()
            ]).then(function (config) {
                var appName = config[0] + "";
                var packageName = config[1] + "";
                var versionCode = config[2] + "";
                var versionNumber = config[3] + "";
                var signalStrength = config[4] + "";
                var networkInformation = config[5] + "";
                var deviceInformation = {
                    uuid: _this.getUuid(),
                    platform: _this.getPlatform(),
                    version: _this.getDeviceVersion(),
                    manufacturer: _this.getManufacturer(),
                    model: _this.getModel(),
                    cordova: _this.getCordovaVersion(),
                    serial: _this.getSerial(),
                    battery: _this.battery,
                    signal: signalStrength,
                    network: networkInformation,
                    appName: appName,
                    packageName: packageName,
                    versionCode: versionCode,
                    versionNumber: versionNumber
                };
                resolve(deviceInformation);
            });
        });
    };
    /**
     * Get network information
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getNetworkInformation = function () {
        return new Promise(function (resolve, reject) {
            if (navigator.hasOwnProperty('connection') && navigator.connection.hasOwnProperty('type')) {
                resolve(navigator.connection.type);
            }
            else {
                resolve('unknown');
            }
        });
    };
    /**
     * Retrieve signal strength
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getSignalStrength = function () {
        return new Promise(function (resolve, reject) {
            if (window.hasOwnProperty('SignalStrength')) {
                window.SignalStrength.dbm(function (data) {
                    resolve(data.toString());
                });
            }
            else {
                resolve('0');
            }
        });
    };
    /**
     * Returns the app name
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getAppName = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isCordova()) {
                cordova.getAppVersion.getAppName().then(function (appName) {
                    resolve(appName);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                resolve('Web App');
            }
        });
    };
    /**
     * Returns the package name
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getPackageName = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isCordova()) {
                cordova.getAppVersion.getPackageName().then(function (packageName) {
                    resolve(packageName);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                resolve('N/A');
            }
        });
    };
    /**
     * Returns the version code
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getVersionCode = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isCordova()) {
                cordova.getAppVersion.getVersionCode().then(function (versionCode) {
                    resolve(versionCode + '');
                }, function (err) {
                    reject(err);
                });
            }
            else {
                resolve('N/A');
            }
        });
    };
    /**
     * Returns the version number
     * @returns {Promise<string>}
     */
    AtajoXDevice.prototype.getVersionNumber = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.isCordova()) {
                cordova.getAppVersion.getVersionNumber().then(function (versionNumber) {
                    resolve(versionNumber);
                }, function (err) {
                    reject(err);
                });
            }
            else {
                resolve('N/A');
            }
        });
    };
    /**
     * Returns the device uuid
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getUuid = function () {
        var browserFingerprint = AtajoXUtils.getBrowserFingerprint();
        return (this.isCordova()) ? device.uuid : browserFingerprint.uuid;
    };
    /**
     * Returns the platform type
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getPlatform = function () {
        var platform = 'unknown';
        if (document.URL.startsWith('http') || document.URL.startsWith('https')) {
            platform = "web";
        }
        return (this.isCordova()) ? device.platform : platform;
    };
    /**
     * Returns the device version
     *
     * @returns {number}
     */
    AtajoXDevice.prototype.getDeviceVersion = function () {
        var browserFingerprint = AtajoXUtils.getBrowserFingerprint();
        return (this.isCordova()) ? device.version : browserFingerprint.majorVersion;
    };
    /**
     * Returns the device manufacturer
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getManufacturer = function () {
        var browserFingerprint = AtajoXUtils.getBrowserFingerprint();
        return (this.isCordova()) ? device.manufacturer : browserFingerprint.name;
    };
    /**
     * Returns the device model
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getModel = function () {
        return (this.isCordova()) ? device.model : '';
    };
    /**
     * Returns the Cordova version
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getCordovaVersion = function () {
        return (this.isCordova()) ? device.cordova : '';
    };
    /**
     * Returns the device serial
     *
     * @returns {string}
     */
    AtajoXDevice.prototype.getSerial = function () {
        return (this.isCordova()) ? device.serial : '';
    };
    /**
     * Checks if Cordova is available
     * This is only true when running on device
     *
     * @returns {boolean}
     */
    AtajoXDevice.prototype.isCordova = function () {
        return typeof cordova !== 'undefined';
    };
    /**
     * Subscribe to battery events
     */
    AtajoXDevice.prototype.addBatteryEventListeners = function () {
        window.addEventListener("batterystatus", this.onBatteryChange, false);
        window.addEventListener("batterylow", this.onBatteryChange, false);
        window.addEventListener("batterycritical", this.onBatteryChange, false);
    };
    /**
     * Set battery state
     *
     * @param {any} status
     * @private
     */
    AtajoXDevice.prototype.onBatteryChange = function (status) {
        this.battery = { level: status.level + '', isCharging: status.isPlugged };
    };
    return AtajoXDevice;
}());
export { AtajoXDevice };
export var atajoXDevice = new AtajoXDevice();
//# sourceMappingURL=device.js.map